@@ -3,7 +3,7 @@ function(path.mcmc,printit=FALSE,file=NULL)
   {
     fileparam <- paste(path.mcmc,"parameters.txt",sep="/")
     param <- as.matrix(read.table(fileparam))
-    stepw <- as.numeric(param[12,3])
+    thinning <- as.numeric(param[param[,1]=="thinning",3])
     
     filenpop <- paste(path.mcmc,"populations.numbers.txt",sep="")
     npop <- scan(filenpop)
@@ -12,7 +12,7 @@ function(path.mcmc,printit=FALSE,file=NULL)
       postscript(file)
       par(mfrow=c(1,2))
       plot(npop,type="l",ylab="Number of classes",
-           xlab=paste("Index of MCMC iteration"," (x ",stepw,")",sep=""),
+           xlab=paste("Index of MCMC iteration"," (x ",thinning,")",sep=""),
            ylim=c(1,max(npop)+0.5))
       hist(npop,plot=TRUE,prob=TRUE,breaks=seq(.5,max(npop)+0.5,1),
            xlab="Number of populations along the chain")
